@@ -217,7 +217,8 @@ CCanvas::CCanvas()
     largeIcons = cfg.value("environment/largeIcons", largeIcons).toBool();
     qApp->installEventFilter(this);
 
-    //setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    setAttribute( (Qt::WidgetAttribute)128, true);
+    setAttribute( (Qt::WidgetAttribute)129, false);
     //connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 }
 
@@ -423,9 +424,9 @@ void CCanvas::slotKey2()
     menu.addAction(5,tr("waypoint"), QIcon(":/icons/waypoint64x64.png"), &CWptDB::self(), SLOT(addWptToPos()));
     menu.addAction(4, tr("back"), QIcon(":/icons/back64x64.png"));
 
-    int y = infoScreen->height();
+    int y = infoScreen->y() + 200;
     int x = (width() - menu.width()) >> 1;
-    menu.exec(QPoint(x,y+5));
+    menu.exec(QPoint(x,y));
 
 }
 
