@@ -30,7 +30,7 @@ CMenu::CMenu(QWidget * parent)
 //: QDialog(parent)
 , current(0)
 {
-    setAttribute(/* Qt::WA_NoSystemBackground */ Qt::WA_TranslucentBackground, true);
+    setAttribute( Qt::WA_NoSystemBackground , true);
     //setAttribute(Qt::WA_Maemo5StackedWindow);
     //setAttribute(Qt::WA_X11NetWmWindowTypePopupMenu);
 
@@ -61,9 +61,10 @@ void CMenu::paintEvent(QPaintEvent */*e*/)
     r.setWidth(r.width() - 1);
     r.setHeight(r.height() - 1);
 
-    p.setBrush(Qt::lightGray);
+    p.setBrush( QBrush(QColor(152,152,215,180)));
     p.setPen(QPen(Qt::black,3));
     p.drawRoundedRect(r,10,10);
+    //p.fillRect(r, Qt::Dense4Pattern);
 
 
     for(i=0; i< 9; ++i){
@@ -71,7 +72,7 @@ void CMenu::paintEvent(QPaintEvent */*e*/)
             if(current == &entries[i]){
 
                 QRect r = entries[i].r;
-                p.setBrush(QBrush(QColor(200,200,255)));
+                p.setBrush(QBrush(QColor(200,200,255,180)));
                 p.setPen(QPen(Qt::yellow,3));
                 p.drawRoundedRect(r, 10, 10);
 
@@ -87,7 +88,7 @@ void CMenu::paintEvent(QPaintEvent */*e*/)
             }
             else{
                 QRect r = entries[i].r;
-                p.setBrush(QBrush(QColor(0,0,255)));
+                p.setBrush(QBrush(QColor(0,0,255,180)));
                 p.setPen(QPen(Qt::white,3));
                 p.drawRoundedRect(r, 10, 10);
 
@@ -102,7 +103,7 @@ void CMenu::paintEvent(QPaintEvent */*e*/)
             }
         }
         else{
-            p.setBrush(QBrush(QColor(100,100,100)));
+            p.setBrush(QBrush(QColor(100,100,100,180)));
             p.setPen(QPen(Qt::darkGray,3));
             p.drawRoundedRect(entries[i].r, 10, 10);
         }
