@@ -51,7 +51,7 @@ CNokia::CNokia(const QString& gpsdevice, int rate, QObject * parent)
 
     satelliteInfo = QGeoSatelliteInfoSource::createDefaultSource(this);
 
-    location->setUpdateInterval(5000);
+    location->setUpdateInterval(1000);
 
     location->startUpdates();
     satelliteInfo->startUpdates();
@@ -86,13 +86,13 @@ void CNokia::encode(const QString& line)
 
 void CNokia::positionUpdated(const QGeoPositionInfo &info)
 {
-    qDebug() << "CNokia::positionUpdated";
     fix = (info.coordinate().type() == QGeoCoordinate::Coordinate3D) ? e3DFix : (info.coordinate().type() == QGeoCoordinate::Coordinate2D) ? e2DFix : eNoFix;
     hdop = info.HorizontalAccuracy;
     vdop = info.VerticalAccuracy;
     lat = info.coordinate().latitude() * DEG_TO_RAD;
     lon = info.coordinate().longitude() * DEG_TO_RAD;
     timestamp = info.timestamp().toTime_t();
+    datetime = info.timestamp().toLocalTime();
     ele = info.coordinate().altitude();
     velocity = info.GroundSpeed;
 
@@ -102,7 +102,6 @@ void CNokia::positionUpdated(const QGeoPositionInfo &info)
 }
 
 void CNokia::slotSatellitesInView( QList<QGeoSatelliteInfo> sats) {
-    qDebug() << "void CNokia::slotSatellitesInView";
     for ( idxSat = 0; idxSat < sats.size() ; idxSat++) {
         QGeoSatelliteInfo info=sats.at(idxSat);
         satellites[idxSat].prn = info.prnNumber();
@@ -124,8 +123,6 @@ void CNokia::slotWatchdog()
 
     fix = eNoFix;
 
-    qDebug() << "void CNokia::slotWatchdog()";
-
     sysError = tr("Try to start GPS.");
     emit sigNewData(*this);
 
